==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/ZlecenieWydaniaWyrobMiesiacKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class ZlecenieWydaniaWyrobMiesiacKey extends GenericDPSObject {
    /**
     * ZLECENIE_WYDANIA_WYROB_MIESIAC.MIESIAC
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Integer miesiac;

    /**
     * ZLECENIE_WYDANIA_WYROB_MIESIAC.ZLECENIE_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long zlecenieId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ZLECENIE_WYDANIA_WYROB_MIESIAC.MIESIAC
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Integer getMiesiac() {
        return miesiac;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:42
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * ZLECENIE_WYDANIA_WYROB_MIESIAC.MIESIAC
     *
     * @param miesiac
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setMiesiac(Integer miesiac) {
        this.miesiac = miesiac;
    }

    /**
     * @return ZLECENIE_WYDANIA_WYROB_MIESIAC.ZLECENIE_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getZlecenieId() {
        return zlecenieId;
    }

    /**
     * ZLECENIE_WYDANIA_WYROB_MIESIAC.ZLECENIE_ID
     *
     * @param zlecenieId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setZlecenieId(Long zlecenieId) {
        this.zlecenieId = zlecenieId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ZlecenieWydaniaWyrobMiesiacKey other = (ZlecenieWydaniaWyrobMiesiacKey) that;
        return (this.getMiesiac() == null ? other.getMiesiac() == null : this.getMiesiac().equals(other.getMiesiac()))
            && (this.getZlecenieId() == null ? other.getZlecenieId() == null : this.getZlecenieId().equals(other.getZlecenieId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getMiesiac() == null) ? 0 : getMiesiac().hashCode());
        result = prime * result + ((getZlecenieId() == null) ? 0 : getZlecenieId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", miesiac=").append(miesiac);
        sb.append(", zlecenieId=").append(zlecenieId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/ZlecenieWydaniaWyrobMiesiacKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class ZlecenieWydaniaWyrobMiesiacKey extends GenericDPSObject {
    /**
     * ZLECENIE_WYDANIA_WYROB_MIESIAC.MIESIAC
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Integer miesiac;

    /**
     * ZLECENIE_WYDANIA_WYROB_MIESIAC.ZLECENIE_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long zlecenieId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ZLECENIE_WYDANIA_WYROB_MIESIAC.MIESIAC
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Integer getMiesiac() {
        return miesiac;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:47
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * ZLECENIE_WYDANIA_WYROB_MIESIAC.MIESIAC
     *
     * @param miesiac
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setMiesiac(Integer miesiac) {
        this.miesiac = miesiac;
    }

    /**
     * @return ZLECENIE_WYDANIA_WYROB_MIESIAC.ZLECENIE_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getZlecenieId() {
        return zlecenieId;
    }

    /**
     * ZLECENIE_WYDANIA_WYROB_MIESIAC.ZLECENIE_ID
     *
     * @param zlecenieId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setZlecenieId(Long zlecenieId) {
        this.zlecenieId = zlecenieId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ZlecenieWydaniaWyrobMiesiacKey other = (ZlecenieWydaniaWyrobMiesiacKey) that;
        return (this.getMiesiac() == null ? other.getMiesiac() == null : this.getMiesiac().equals(other.getMiesiac()))
            && (this.getZlecenieId() == null ? other.getZlecenieId() == null : this.getZlecenieId().equals(other.getZlecenieId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getMiesiac() == null) ? 0 : getMiesiac().hashCode());
        result = prime * result + ((getZlecenieId() == null) ? 0 : getZlecenieId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", miesiac=").append(miesiac);
        sb.append(", zlecenieId=").append(zlecenieId);
        sb.append("]");
        return sb.toString();
    }
}
